@@ -1,7 +1,10 @@
 package Math::Business::BlackScholes::Binaries::Greeks;
-use strict; use warnings;
+use strict;
+use warnings;
 
-our $VERSION = '0.04';
+# ABSTRACT: calculate the sensitivity of the price of binary options
+
+our $VERSION = '0.05';
 
 1;
 
@@ -11,10 +14,6 @@ __END__
 
 Math::Business::BlackScholes::Binaries::Greeks
 
-=head1 VERSION
-
-Version 0.04
-
 =head1 SYNOPSIS
 
     use Math::Business::BlackScholes::Binaries::Greeks::Delta;
@@ -49,7 +48,7 @@ change in the underlying parameters of the financial asset.
 
 B<First-order Greeks>
 
-=over 4 
+=over 4
 
 =item * Math::Business::BlackScholes::Binaries::Greeks::Delta
 
@@ -61,7 +60,7 @@ B<First-order Greeks>
 
 B<Second-order Greeks>
 
-=over 4 
+=over 4
 
 =item * Math::Business::BlackScholes::Binaries::Greeks::Gamma
 
@@ -294,45 +293,5 @@ L<http://search.cpan.org/dist/Math-Business-BlackScholes-Binaries-Greeks/>
 =back
 
 
-=head1 LICENSE AND COPYRIGHT
-
-Copyright 2014 binary.com.
-
-This program is free software; you can redistribute it and/or modify it
-under the terms of the the Artistic License (2.0). You may obtain a
-copy of the full license at:
-
-L<http://www.perlfoundation.org/artistic_license_2_0>
-
-Any use, modification, and distribution of the Standard or Modified
-Versions is governed by this Artistic License. By using, modifying or
-distributing the Package, you accept this license. Do not use, modify,
-or distribute the Package, if you do not accept this license.
-
-If your Modified Version has been derived from a Modified Version made
-by someone other than you, you are nevertheless required to ensure that
-your Modified Version complies with the requirements of this license.
-
-This license does not grant you the right to use any trademark, service
-mark, tradename, or logo of the Copyright Holder.
-
-This license includes the non-exclusive, worldwide, free-of-charge
-patent license to make, have made, use, offer to sell, sell, import and
-otherwise transfer the Package with respect to any patent claims
-licensable by the Copyright Holder that are necessarily infringed by the
-Package. If you institute patent litigation (including a cross-claim or
-counterclaim) against any party alleging that the Package constitutes
-direct or contributory patent infringement, then this Artistic License
-to you shall terminate on the date that such litigation is filed.
-
-Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER
-AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES.
-THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY
-YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR
-CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
-CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
-EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-
 =cut
 
