@@ -1,7 +1,8 @@
 package Math::Business::BlackScholes::Binaries::Greeks::Math;
-use strict; use warnings;
+use strict;
+use warnings;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';    ## VERSION
 
 =head1 NAME
 
